@@ -1,3 +1,17 @@
+# SUNContext support for SUNDIALS 6.0+
+const SUNContext = Ptr{Cvoid}
+
+# SUNContext functions
+function SUNContext_Create(comm::Ptr{Cvoid}, ctx::Ptr{SUNContext})
+    ccall((:SUNContext_Create, libsundials_core), Cint,
+        (Ptr{Cvoid}, Ptr{SUNContext}), comm, ctx)
+end
+
+function SUNContext_Free(ctx::SUNContext)
+    ctx_ptr = Ref(ctx)
+    ccall((:SUNContext_Free, libsundials_core), Cint, (Ptr{SUNContext},), ctx_ptr)
+end
+
 struct klu_l_symbolic
     symmetry::Cdouble
     est_flops::Cdouble
@@ -992,9 +1006,9 @@ const ARK_NORMAL = Cint(1)
 
 const ARK_ONE_STEP = Cint(2)
 
-const ARK_INTERP_MAX_DEGREE = Cint(5)
+const ARK_INTERP_MAX_DEGREE = Cint(7)
 
-const ARK_INTERP_HERMITE = Cint(0)
+const ARK_INTERP_HERMITE = Cint(4)
 
 const ARK_INTERP_LAGRANGE = Cint(1)
 
