@@ -3,7 +3,8 @@
 # Abstract Types
 abstract type SundialsODEAlgorithm{Method, LinearSolver} <: DiffEqBase.AbstractODEAlgorithm end
 abstract type SundialsDAEAlgorithm{LinearSolver} <: DiffEqBase.AbstractDAEAlgorithm end
-abstract type SundialsNonlinearSolveAlgorithm{LinearSolver} <: SciMLBase.AbstractNonlinearAlgorithm end
+abstract type SundialsNonlinearSolveAlgorithm{LinearSolver} <:
+              SciMLBase.AbstractNonlinearAlgorithm end
 
 SciMLBase.alg_order(alg::Union{SundialsODEAlgorithm, SundialsDAEAlgorithm}) = alg.max_order
 
@@ -40,8 +41,8 @@ The choices for the linear solver are:
 
 * :Dense - A dense linear solver.
 * :Band - A solver specialized for banded Jacobians. If used, you must set the position of the upper and lower non-zero diagonals via jac_upper and jac_lower.
-* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticable overhead on smaller (<100 ODE) systems.
-* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticable overhead on smaller (<100 ODE) systems.
+* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
+* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
 * :Diagonal - This method is specialized for diagonal Jacobians.
 * :GMRES - A GMRES method. Recommended first choice Krylov method
 * :BCG - A Biconjugate gradient method.
@@ -108,21 +109,21 @@ struct CVODE_BDF{Method, LinearSolver, P, PS} <: SundialsODEAlgorithm{Method, Li
     prec_side::Int
 end
 Base.@pure function CVODE_BDF(;
-    method = :Newton,
-    linear_solver = :Dense,
-    jac_upper = 0,
-    jac_lower = 0,
-    non_zero = 0,
-    krylov_dim = 0,
-    stability_limit_detect = false,
-    max_hnil_warns = 10,
-    max_order = 5,
-    max_error_test_failures = 7,
-    max_nonlinear_iters = 3,
-    max_convergence_failures = 10,
-    prec = nothing,
-    psetup = nothing,
-    prec_side = 0)
+        method = :Newton,
+        linear_solver = :Dense,
+        jac_upper = 0,
+        jac_lower = 0,
+        non_zero = 0,
+        krylov_dim = 0,
+        stability_limit_detect = false,
+        max_hnil_warns = 10,
+        max_order = 5,
+        max_error_test_failures = 7,
+        max_nonlinear_iters = 3,
+        max_convergence_failures = 10,
+        prec = nothing,
+        psetup = nothing,
+        prec_side = 0)
     if linear_solver == :Band && (jac_upper == 0 || jac_lower == 0)
         error("Banded solver must set the jac_upper and jac_lower")
     end
@@ -185,8 +186,8 @@ The choices for the linear solver are:
 
 * :Dense - A dense linear solver.
 * :Band - A solver specialized for banded Jacobians. If used, you must set the position of the upper and lower non-zero diagonals via jac_upper and jac_lower.
-* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticable overhead on smaller (<100 ODE) systems.
-* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticable overhead on smaller (<100 ODE) systems.
+* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
+* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
 * :Diagonal - This method is specialized for diagonal Jacobians.
 * :GMRES - A GMRES method. Recommended first choice Krylov method
 * :BCG - A Biconjugate gradient method.
@@ -254,20 +255,20 @@ struct CVODE_Adams{Method, LinearSolver, P, PS} <:
     prec_side::Int
 end
 Base.@pure function CVODE_Adams(;
-    method = :Functional,
-    linear_solver = :None,
-    jac_upper = 0,
-    jac_lower = 0,
-    krylov_dim = 0,
-    stability_limit_detect = false,
-    max_hnil_warns = 10,
-    max_order = 12,
-    max_error_test_failures = 7,
-    max_nonlinear_iters = 3,
-    max_convergence_failures = 10,
-    prec = nothing,
-    psetup = nothing,
-    prec_side = 0)
+        method = :Functional,
+        linear_solver = :None,
+        jac_upper = 0,
+        jac_lower = 0,
+        krylov_dim = 0,
+        stability_limit_detect = false,
+        max_hnil_warns = 10,
+        max_order = 12,
+        max_error_test_failures = 7,
+        max_nonlinear_iters = 3,
+        max_convergence_failures = 10,
+        prec = nothing,
+        psetup = nothing,
+        prec_side = 0)
     if linear_solver == :Band && (jac_upper == 0 || jac_lower == 0)
         error("Banded solver must set the jac_upper and jac_lower")
     end
@@ -388,8 +389,8 @@ The choices for the linear solver are:
 
 * :Dense - A dense linear solver.
 * :Band - A solver specialized for banded Jacobians. If used, you must set the position of the upper and lower non-zero diagonals via jac_upper and jac_lower.
-* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticable overhead on smaller (<100 ODE) systems.
-* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticable overhead on smaller (<100 ODE) systems.
+* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
+* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
 * :Diagonal - This method is specialized for diagonal Jacobians.
 * :GMRES - A GMRES method. Recommended first choice Krylov method
 * :BCG - A Biconjugate gradient method.
@@ -462,35 +463,35 @@ struct ARKODE{Method, LinearSolver, MassLinearSolver, T, T1, T2, P, PS} <:
 end
 
 Base.@pure function ARKODE(stiffness = Implicit();
-    method = :Newton,
-    linear_solver = :Dense,
-    mass_linear_solver = :Dense,
-    jac_upper = 0,
-    jac_lower = 0,
-    mass_upper = 0,
-    mass_lower = 0,
-    non_zero = 0,
-    krylov_dim = 0,
-    mass_krylov_dim = 0,
-    max_hnil_warns = 10,
-    max_error_test_failures = 7,
-    max_nonlinear_iters = 3,
-    max_convergence_failures = 10,
-    predictor_method = 0,
-    nonlinear_convergence_coefficient = 0.1,
-    dense_order = 3,
-    order = 4,
-    set_optimal_params = false,
-    crdown = 0.3,
-    dgmax = 0.2,
-    rdiv = 2.3,
-    msbp = 20,
-    adaptivity_method = 0,
-    itable = nothing,
-    etable = nothing,
-    prec = nothing,
-    psetup = nothing,
-    prec_side = 0)
+        method = :Newton,
+        linear_solver = :Dense,
+        mass_linear_solver = :Dense,
+        jac_upper = 0,
+        jac_lower = 0,
+        mass_upper = 0,
+        mass_lower = 0,
+        non_zero = 0,
+        krylov_dim = 0,
+        mass_krylov_dim = 0,
+        max_hnil_warns = 10,
+        max_error_test_failures = 7,
+        max_nonlinear_iters = 3,
+        max_convergence_failures = 10,
+        predictor_method = 0,
+        nonlinear_convergence_coefficient = 0.1,
+        dense_order = 3,
+        order = 4,
+        set_optimal_params = false,
+        crdown = 0.3,
+        dgmax = 0.2,
+        rdiv = 2.3,
+        msbp = 20,
+        adaptivity_method = 0,
+        itable = nothing,
+        etable = nothing,
+        prec = nothing,
+        psetup = nothing,
+        prec_side = 0)
     if linear_solver == :Band && (jac_upper == 0 || jac_lower == 0)
         error("Banded solver must set the jac_upper and jac_lower")
     end
@@ -587,8 +588,8 @@ choices are:
 
 * :Dense - A dense linear solver.
 * :Band - A solver specialized for banded Jacobians. If used, you must set the position of the upper and lower non-zero diagonals via jac_upper and jac_lower.
-* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticable overhead on smaller (<100 ODE) systems.
-* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticable overhead on smaller (<100 ODE) systems.
+* :LapackDense - A version of the dense linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Dense on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
+* :LapackBand - A version of the banded linear solver that uses the Julia-provided OpenBLAS-linked LAPACK for multithreaded operations. This will be faster than :Band on larger systems but has noticeable overhead on smaller (<100 ODE) systems.
 * :GMRES - A GMRES method. Recommended first choice Krylov method
 * :BCG - A Biconjugate gradient method.
 * :PCG - A preconditioned conjugate gradient method. Only for symmetric linear systems.
@@ -660,24 +661,24 @@ struct IDA{LinearSolver, P, PS} <: SundialsDAEAlgorithm{LinearSolver}
     psetup::PS
 end
 Base.@pure function IDA(;
-    linear_solver = :Dense,
-    jac_upper = 0,
-    jac_lower = 0,
-    krylov_dim = 0,
-    max_order = 5,
-    max_error_test_failures = 7,
-    max_nonlinear_iters = 3,
-    nonlinear_convergence_coefficient = 0.33,
-    nonlinear_convergence_coefficient_ic = 0.0033,
-    max_num_steps_ic = 5,
-    max_num_jacs_ic = 4,
-    max_num_iters_ic = 10,
-    max_num_backs_ic = 100,
-    use_linesearch_ic = true,
-    init_all = false,
-    max_convergence_failures = 10,
-    prec = nothing,
-    psetup = nothing)
+        linear_solver = :Dense,
+        jac_upper = 0,
+        jac_lower = 0,
+        krylov_dim = 0,
+        max_order = 5,
+        max_error_test_failures = 7,
+        max_nonlinear_iters = 3,
+        nonlinear_convergence_coefficient = 0.33,
+        nonlinear_convergence_coefficient_ic = 0.0033,
+        max_num_steps_ic = 5,
+        max_num_jacs_ic = 4,
+        max_num_iters_ic = 10,
+        max_num_backs_ic = 100,
+        use_linesearch_ic = true,
+        init_all = false,
+        max_convergence_failures = 10,
+        prec = nothing,
+        psetup = nothing)
     if linear_solver == :Band && (jac_upper == 0 || jac_lower == 0)
         error("Banded solver must set the jac_upper and jac_lower")
     end
@@ -772,14 +773,14 @@ struct KINSOL{LinearSolver} <: SundialsNonlinearSolveAlgorithm{LinearSolver}
 end
 
 Base.@pure function KINSOL(;
-    linear_solver = :Dense,
-    jac_upper = 0,
-    jac_lower = 0,
-    userdata = nothing,
-    prec_side = 0,
-    krylov_dim = 0,
-    globalization_strategy = :None,
-    maxsetupcalls = 0)
+        linear_solver = :Dense,
+        jac_upper = 0,
+        jac_lower = 0,
+        userdata = nothing,
+        prec_side = 0,
+        krylov_dim = 0,
+        globalization_strategy = :None,
+        maxsetupcalls = 0)
     if !(linear_solver in (:None,
         :Dense,
         :LapackDense,
@@ -797,23 +798,23 @@ Base.@pure function KINSOL(;
         error("Globalization strategy not accepted.")
     end
     KINSOL{linear_solver}(jac_upper, jac_lower, userdata, prec_side, krylov_dim,
-    globalization_strategy, maxsetupcalls)
+        globalization_strategy, maxsetupcalls)
 end
 
 method_choice(alg::SundialsODEAlgorithm{Method}) where {Method} = Method
 method_choice(alg::SundialsDAEAlgorithm) = :Newton
 function linear_solver(alg::SundialsODEAlgorithm{
-    Method,
-    LinearSolver,
+        Method,
+        LinearSolver
 }) where {Method,
-    LinearSolver}
+        LinearSolver}
     LinearSolver
 end
 linear_solver(alg::SundialsDAEAlgorithm{LinearSolver}) where {LinearSolver} = LinearSolver
 function linear_solver(alg::SundialsNonlinearSolveAlgorithm{
-    LinearSolver,
+        LinearSolver,
 }) where {
-    LinearSolver,
+        LinearSolver,
 }
     LinearSolver
 end
