@@ -12,8 +12,8 @@ f_error2(du, u, p, t) = du .= u ./ t .- 1
 u0 = [1.0];
 du0 = [1.0];
 prob = DAEProblem(f_error2, u0, du0, (0.0, 1.0); differential_vars = [true])
-sol = solve(prob, IDA())
-sol = solve(prob, IDA(); verbose = false)
+sol = solve(prob, IDA(), initializealg = Sundials.BrownFullBasicInit())
+sol = solve(prob, IDA(); initializealg = Sundials.BrownFullBasicInit(), verbose = false)
 
 @test sol.retcode == ReturnCode.InitialFailure
 
